@@ -1,5 +1,5 @@
 package IRC::Message::Object;
-$IRC::Message::Object::VERSION = '0.091001';
+$IRC::Message::Object::VERSION = '0.092001';
 use strictures 2;
 use Carp;
 
@@ -13,7 +13,7 @@ sub ircmsg { __PACKAGE__->new(@_) }
 our @EXPORT = our @EXPORT_OK = 'ircmsg';
 
 
-use Moo;
+use Moo; use MooX::TypeTiny;
 extends 'Exporter::Tiny';
 
 has colonify => (
