@@ -1,5 +1,5 @@
 package IRC::Toolkit::CTCP;
-$IRC::Toolkit::CTCP::VERSION = '0.091001';
+$IRC::Toolkit::CTCP::VERSION = '0.092001';
 use strictures 2;
 use Carp 'confess';
 
@@ -34,7 +34,7 @@ sub ctcp_quote {
   }
 
   $line =~ s/\001/\\a/g;
-  "\001$line\001";
+  "\001$line\001"
 }
 
 sub ctcp_unquote {
@@ -51,12 +51,8 @@ sub ctcp_unquote {
 
   my @chunks = split /\001/, $line;
   shift @chunks unless length $chunks[0];
-  for (@chunks) {
-    ## De-quote / convert escapes
-    s/\\([^\\a])/$1/g;
-    s/\\\\/\\/g;
-    s/\\a/\001/g;
-  }
+  ## De-quote / convert escapes
+  s/\\([^\\a])/$1/g, s/\\\\/\\/g, s/\\a/\001/g for @chunks;
 
   my (@ctcp, @text);
 
@@ -117,7 +113,8 @@ sub ctcp_extract {
       )
     }
   }
-  return
+  
+  undef
 }
 
 
@@ -171,7 +168,8 @@ to the CTCP command:
   ## DCC SEND:
   $ev->command eq 'dcc_request_send' 
 
-Returns empty list if no valid CTCP was found.
+Returns C<undef> if no valid CTCP was found; this is a breaking change in
+C<v0.91.2>, as previous versions returned the empty list.
 
 =head2 ctcp_quote
 
