@@ -1,5 +1,5 @@
 package IRC::Toolkit::ISupport;
-$IRC::Toolkit::ISupport::VERSION = '0.091001';
+$IRC::Toolkit::ISupport::VERSION = '0.092001';
 use strictures 2;
 
 use Carp          'confess';
@@ -132,10 +132,7 @@ sub _isupport_hash {
   \%cur
 }
 
-sub _isupport_hash_to_obj {
-  my ($isupport_hash) = @_;
-  IRC::Toolkit::ISupport::Obj->__new($isupport_hash)
-}
+sub _isupport_hash_to_obj { IRC::Toolkit::ISupport::Obj->__new($_[0]) }
 
 sub parse_isupport {
   my @items = map {;
@@ -165,10 +162,7 @@ sub parse_isupport {
   IRC::Toolkit::_ISchanmodes;
   use Carp 'confess';
   use strictures 2;
-  sub new {
-    my ($cls, %self) = @_;
-    bless +{%self}, $cls 
-  }
+  sub new { bless +{ @_[1 .. $#_] }, $_[0] }
 
   sub list    { $_[0]->{list} }
   sub always  { $_[0]->{always} }
@@ -189,10 +183,7 @@ sub parse_isupport {
   IRC::Toolkit::_ISextban;
   use Carp 'confess';
   use strictures 2;
-  sub new {
-    my ($cls, %self) = @_;
-    bless +{%self}, $cls
-  }
+  sub new { bless +{ @_[1 .. $#_] }, $_[0] }
 
   sub prefix { $_[0]->{prefix} }
   sub flags  { $_[0]->{flags}  }
