@@ -1,10 +1,10 @@
 package IRC::Toolkit::Numerics;
-$IRC::Toolkit::Numerics::VERSION = '0.091001';
+$IRC::Toolkit::Numerics::VERSION = '0.092001';
 use strictures 2;
 use Carp 'confess';
 use List::Objects::WithUtils 'hash';
 
-use Module::Runtime 'use_module';
+use Module::Runtime 'use_package_optimistically';
 
 use parent 'Exporter::Tiny';
 our @EXPORT = qw/
@@ -350,7 +350,8 @@ sub new {
   my ($cls, $type) = splice @_, 0, 2;
 
   if ($type) {
-    return use_module('IRC::Toolkit::Numeric::'.$type)->new(@_)
+    return
+      use_package_optimistically('IRC::Toolkit::Numerics::'.$type)->new(@_)
   }
 
   bless +{ over_num => hash(), over_name => hash() }, $cls
@@ -505,6 +506,23 @@ remapped via L</associate_numeric> are included in the exported hash.
 Like L</export>, but returns the reversed hash (mapping RPL/ERR names to
 numerics).
 
+=head1 SUBCLASSING
+
+It's possible for a subclass to override individual numerics (and otherwise
+default to the standard list) by providing a constructor that uses
+L<List::Objects::WithUtils> to construct C<hash>-type objects containing
+overrides:
+
+  package My::Numerics;
+  use List::Objects::WithUtils 'hash';
+  use parent 'IRC::Toolkit::Numerics';
+  sub new {
+    bless +{
+      over_num  => hash(304 => 'RPL_FOO'),
+      over_name => hash(RPL_RPL => 304),
+    }, $_[0]
+  }
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
